#!/bin/bash
#
# Copyright (C) 2024 MOXA Inc. All rights reserved.
# This software is distributed under the terms of the MOXA SOFTWARE NOTICE.
# See the file LICENSE for details.
#
# Authors:
#       2024  Wilson YS Huang  <wilsonys.huang@moxa.com>

source "${INSTL_SCRIPT_DIR}/lib/util.sh"
source "${INSTL_SCRIPT_DIR}/lib/logger.sh"
log::init "${INSTL_LOG_FILE}" "${INSTL_LOG_LEVEL}"

set -e

REPO_NAME="watchdog"
SRC_PATH_PREFIX="${INSTL_TOP_DIR}/src/${REPO_NAME}"

main() {
        local src_tag
        local src_ver
        src_tag="$1"
        src_ver="$2"

        log::info "Installing ${REPO_NAME} (${src_ver})"

        {
                pushd "${SRC_PATH_PREFIX}-${src_tag}" >/dev/null

                if ! util::is_exists "Makefile"; then
                        ./configure
                fi

                make clean
                make
                make install
                make install-data-local
                install -Dp -m0644 watchdog.service /lib/systemd/system/watchdog.service
                systemctl daemon-reload

                popd
        } >>"${INSTL_LOG_FILE}" 2>&1

        log::info " Setup Watchdog Service"

        {
                sed -i "/^#watchdog-device/s/^#//g" /etc/watchdog.conf
                systemctl enable watchdog
                systemctl start watchdog
        } >>"${INSTL_LOG_FILE}" 2>&1
}

main "$@"
